/// <reference types="node" />
import { ConnectionConfig, Connection, PublicKey, Transaction, TransactionInstruction } from '@solana/web3.js';
import { IWallet } from '.';
/**
 * Builder to create a transaction
 */
export declare class TransactionBuilder {
    private _transaction;
    private _instructions;
    private _connection;
    private _owner;
    private _logger;
    /**
     * Creates a new transaction builder.
     * @param connection - web3 connection
     * @param owner - owner's public key
     */
    constructor(connection: Connection, owner: PublicKey);
    /**
     * Creates a new transaction builder with a custom connection.
     * @param rpcUrl - RPC url
     * @param owner - owner's public key
     * @param config - connection config
     * @returns Transaction builder
     */
    static buildWithConnection(rpcUrl: string, owner: PublicKey, config?: ConnectionConfig): TransactionBuilder;
    /**
     * Adds a token transfer instruction to the transaction if an associated account is not found.
     * @param mint - Public key of the mint
     */
    addCreateTokenAccountIfNotExists(mint: PublicKey): Promise<TransactionBuilder>;
    /**
     * Adds a request compute increase instruction to the transaction.
     * @param units - number of computer units to request, defaults to 256,000.
     */
    addIncreaseComputeInstruction(units?: number): TransactionBuilder;
    /**
     * Saves an instruction to be added to the transaction when built.
     * @param instruction
     */
    add(instruction: TransactionInstruction | TransactionInstruction[]): TransactionBuilder;
    /**
     * Sends and confirms a signed transaction.
     * @param serialisedTx - serialised and signed transaction
     * @returns Transaction signature
     */
    sendAndConfirm(serialisedTx: Uint8Array | Buffer | number[]): Promise<string>;
    /**
     * Sends and confirms a signed transaction. Will retry to send if the transaction fails.
     * @param serialisedTx - serialised and signed transaction
     * @param maximumRetries - number of retries
     * @returns Transaction signature
     */
    sendAndConfirmWithRetry(serialisedTx: Uint8Array | Buffer | number[], maximumRetries?: number): Promise<string>;
    /**
     * Clears the instructions and resets the existing transaction.
     */
    clear(): TransactionBuilder;
    /**
     * Builds a transaction. Adds instructions to the transaction, updates recent blockhash and fee payer.
     */
    build(): Promise<Transaction>;
    /**
     * Builds and signs the transaction.
     * @param wallet - Signing wallet
     * @returns Signed transaction
     */
    buildAndSign(wallet: IWallet): Promise<Transaction>;
    /**
     * Builds, signs, sends and confirms a transaction.
     * @param wallet - Signing wallet
     * @returns Transaction signature
     */
    buildSignSendAndConfirm(wallet: IWallet): Promise<string>;
    /**
     *
     * @param transaction
     * @returns
     */
    rebuild(transaction: Transaction): Promise<Transaction>;
}
